@@ -1,6 +1,6 @@
 `designdist` <-
-    function (x, method = "(A+B-2*J)/(A+B)",
-              terms = c("binary", "quadratic", "minimum"), name) 
+function (x, method = "(A+B-2*J)/(A+B)", terms = c("binary", 
+    "quadratic", "minimum"), name) 
 {
     terms <- match.arg(terms)
     x <- as.matrix(x)
@@ -20,10 +20,11 @@
     B <- as.dist(outer(d, rep(1, N)))
     J <- as.dist(x)
     dis <- eval(parse(text = method))
+    attributes(dis) <- attributes(J)
     attr(dis, "call") <- match.call()
-    if (missing(name))
-        attr(dis, "method") <- paste(method, terms)
-    else
-        attr(dis, "method") <- name
+    if (missing(name)) 
+        attr(dis, "method") <- paste(terms, method)
+    else attr(dis, "method") <- name
     dis
 }
+
