@@ -1,5 +1,5 @@
-"print.metaMDS" <-
-function (x, ...) 
+`print.metaMDS` <-
+    function (x, ...) 
 {
     cat("\nCall:\n")
     cat(deparse(x$call), "\n\n")
@@ -12,14 +12,23 @@ function (x, ...)
         cat("Two convergent solutions found after", x$tries, 
             "tries\n")
     else cat("No convergent solutions - best solution after", 
-        x$tries, "tries\n")
+             x$tries, "tries\n")
     z <- x$points
-    scal <- c(if (attr(z, "centre")) "centring", if (attr(z, 
-        "pc")) "PC rotation", if (attr(z, "halfchange")) "halfchange scaling")
-    if(!length(scal))
+    scal <- c(if (attr(z, "centre")) "centring",
+              if (attr(z, "pc")) "PC rotation",
+              if (attr(z, "halfchange")) "halfchange scaling")
+    if (!length(scal)) 
         scal <- "as is"
     cat("Scaling:", paste(scal, collapse = ", "), "\n")
+    if (all(is.na(x$species))) {
+        cat("Species: scores missing\n")
+    } else {
+        spattr <- attr(x$species, "shrinkage")
+        if (is.null(spattr))
+            cat("Species: non-expanded scores\n")
+        else
+            cat("Species: expanded scores\n")
+    }
     cat("\n")
     invisible(x)
 }
-
