@@ -19,10 +19,10 @@
     wt <- rep(1, length(x))
     logJ <- log(sum(x))
     p <- qlogis(0.1)
-    canon <- try(nlm(canfun, p = p, x = x, rnk = rnk, logJ = logJ, wt = wt,
-                     hessian = TRUE, ...))
+    canon <- try(nlm(canfun, p = p, x = x, rnk = rnk, logJ = logJ, 
+                     wt = wt, hessian = TRUE, ...))
     if (inherits(canon, "try-error")) {
-        aic <- rdf <- devaince <- NA
+        aic <- rdf <- deviance <- NA
         p <- rep(NA, 1)
         fit <- residuals <- prior.weights <- rep(NA, length(x))
     }
@@ -31,15 +31,15 @@
         fit <- exp(logJ + log(p) + log(1 - p) * rnk)
         res <- dev.resids(x, fit, wt)
         deviance <- sum(res)
-        residuals <- x-fit
-        aic <- aicfun(x, rep(1, length(x)), fit, wt, res) + 2
+        residuals <- x - fit
+        aic <- aicfun(x, rep(1, length(x)), fit, wt, deviance) + 2
         rdf <- length(x) - 1
     }
     names(p) <- c("alpha")
-    out <- list(model = "Preemption", family = fam, 
-                y = x, coefficients = p, fitted.values = fit, aic = aic, rank = 1, 
-                df.residual = rdf, deviance = deviance, residuals = residuals,
-                prior.weights=wt)
+    out <- list(model = "Preemption", family = fam, y = x, coefficients = p, 
+                fitted.values = fit, aic = aic, rank = 1, df.residual = rdf, 
+                deviance = deviance, residuals = residuals, prior.weights = wt)
     class(out) <- c("radline", "glm")
     out
 }
+
