@@ -1,4 +1,4 @@
-"summary.cca" <-
+`summary.cca` <-
     function (object, scaling = 2, axes = 6, display=c("sp","wa","lc","bp","cn"), 
               digits = max(3, getOption("digits") - 3), ...) 
 {
@@ -6,6 +6,13 @@
     summ <- list()
     if (axes && length(display) && (!is.na(display) && !is.null(display))) 
         summ <- scores(object, scaling = scaling, choices = 1:axes, display = display, ...)
+    ## scores() drops list to a matrix if there is only one item: workaround below.
+    if (!is.list(summ) && length(display) == 1) {
+        nms <- c("species", "sites", "constraints", "biplot", "centroids")
+        names(nms) <- c("sp","wa","lc","bp","cn")
+        summ <- list(summ)
+        names(summ) <- nms[display]
+    }
     summ$call <- object$call
     summ$tot.chi <- object$tot.chi
     summ$partial.chi <- object$pCCA$tot.chi
